Re-exports
pub use config::CliConfig;pub use devtools::DevToolWidget;pub use devtools::DevToolsDashboard;pub use devtools::LogEntry;pub use devtools::LogLevel;pub use devtools::Panel;pub use devtools::PanelContent;pub use devtools::PerfMetrics;pub use devtools::capture_metrics;pub use devtools::current_timestamp;pub use devtools::format_log_entry;pub use devtools::update_metrics;pub use error::CliError;pub use error::exit_with_error;pub use native_shell::NativeShell;pub use native_shell::ShellBackend;pub use native_shell::ShellError;pub use native_shell::ShellWindow;pub use native_shell::WindowEvent;pub use native_shell::create_window;pub use native_shell::poll_events;pub use scaffold::Scaffolder;pub use scaffold::Template;pub use token_export::TokenExport;pub use ws_server::AppState;pub use ws_server::DevtoolsCommand;pub use ws_server::DevtoolsMessage;pub use ws_server::WsMessage;pub use ws_server::create_router;pub use ws_server::start_file_watcher;pub use ws_server::start_server;
Modules
- agent_
replay - Agent Replay Module Load and replays agent traces for debugging
- asset_
pipeline - Asset Pipeline Hook Handles validation and optimization of static assets like shaders, fonts, and images.
- build_
pipeline - Build Pipeline Hook Hooks into the build process for incremental rebuilds
- config
- Configuration file support for the CVKG CLI.
- dev_
runtime - Dev Runtime Controller Responsible for launching runtime, maintaining connection, and coordinating updates
- devtools
- DevTools Dashboard Module
- devtools_
dashboard - error
- CLI error types for user-friendly error reporting.
- native_
shell - Native Shell Module
- patch_
engine - Patch Engine Responsible for generating patches from compiled artifacts
- plugin
- Plugin system for extending the CVKG CLI.
- raster_
export - Raster export – Exports rendered views to PNG and GIF formats.
- runtime_
connection - Runtime Connection Layer Handles communication between CLI and running app
- scaffold
- token_
export - Design Token Export – Item 13
- webkit_
server - WebKit Preview Server Serves the host shell and WASM bundle for app preview
- ws_
server - WebSocket Server Multiplexed WebSocket server for runtime communication, DevTools, hot reload, and agent streams