pub struct BuildPipeline;Expand description
Build pipeline hook
Implementations
Sourceimpl BuildPipeline
impl BuildPipeline
Sourcepub fn compile_project<P: AsRef<Path>>(
project_path: P,
target: Option<&str>,
release: bool,
features: &[String],
) -> CompiledArtifact
pub fn compile_project<P: AsRef<Path>>( project_path: P, target: Option<&str>, release: bool, features: &[String], ) -> CompiledArtifact
Compile the project using cargo build with support for targets and features.
Sourcepub fn watch_changes<P: AsRef<Path>, F>(project_path: P, callback: F)
pub fn watch_changes<P: AsRef<Path>, F>(project_path: P, callback: F)
Watch for file changes and trigger incremental rebuilds with debouncing