pub fn current_timestamp() -> StringExpand description
Create a timestamp string suitable for LogEntry::timestamp.
Returns the current system time formatted as a Unix timestamp string.
pub fn current_timestamp() -> StringCreate a timestamp string suitable for LogEntry::timestamp.
Returns the current system time formatted as a Unix timestamp string.