pub fn dashboard_state() -> Option<Arc<Mutex<GraphState>>>Expand description
Get the global dashboard state for updating from the file watcher.
pub fn dashboard_state() -> Option<Arc<Mutex<GraphState>>>Get the global dashboard state for updating from the file watcher.