Module native_shell

Module native_shell 

Native Shell Module

Provides a unified interface for creating and managing native application windows through multiple backend implementations: Tauri, Wry, or Headless (for testing and CI environments).

Structs

NativeShell
Configuration and handle for a native shell instance.
ShellError
Errors that can occur when creating or managing native shell windows.
ShellWindow
A handle to a created native window.

Enums

ShellBackend
The rendering backend used for the native shell window.
WindowEvent
Events that can be emitted by a native window.

Functions

create_window
Create a native window from the given NativeShell configuration.
poll_events
Poll for pending window events in a non-blocking fashion.