pub struct PatchEngine { /* private fields */ }Expand description
Patch Engine implementation PatchEngine — Responsible for generating atomic updates between build artifacts.
The PatchEngine diffs serialized view trees from the Muspelheim build pipeline to produce minimal patches for runtime hot-reloading.
Implementations
Sourceimpl PatchEngine
impl PatchEngine
Sourcepub fn generate_patch(&mut self, artifact: CompiledArtifact) -> RuntimePatch
pub fn generate_patch(&mut self, artifact: CompiledArtifact) -> RuntimePatch
Generate a patch from a compiled artifact