pub type DashboardState = Arc<Mutex<GraphState>>;Expand description
Shared dashboard state, populated by the dev server and file watcher.
Aliased Type
pub struct DashboardState { /* private fields */ }pub type DashboardState = Arc<Mutex<GraphState>>;Shared dashboard state, populated by the dev server and file watcher.
pub struct DashboardState { /* private fields */ }