Re-exports
pub use devtools::DevToolWidget;pub use devtools::DevToolsDashboard;pub use devtools::LogEntry;pub use devtools::LogLevel;pub use devtools::Panel;pub use devtools::PanelContent;pub use devtools::PerfMetrics;pub use devtools::capture_metrics;pub use devtools::current_timestamp;pub use devtools::format_log_entry;pub use native_shell::NativeShell;pub use native_shell::ShellBackend;pub use native_shell::ShellError;pub use native_shell::ShellWindow;pub use native_shell::WindowEvent;pub use native_shell::create_window;pub use native_shell::poll_events;
Modules
- agent_
replay - Agent Replay Module Load and replays agent traces for debugging
- build_
pipeline - Build Pipeline Hook Hooks into the build process for incremental rebuilds
- dev_
runtime - Dev Runtime Controller Responsible for launching runtime, maintaining connection, and coordinating updates
- devtools
- DevTools Dashboard Module
- native_
shell - Native Shell Module
- patch_
engine - Patch Engine Responsible for generating patches from compiled artifacts
- runtime_
connection - Runtime Connection Layer Handles communication between CLI and running app
- ws_
server - WebSocket Server Multiplexed WebSocket server for runtime communication, DevTools, hot reload, and agent streams