Module devtools_dashboard

Module devtools_dashboard 

Structs

DashboardConfig
Configuration for the DevTools dashboard server.
EdgeInfo
Edge information for the dashboard.
EventInfo
Event information for the dashboard.
GraphState
Serializable graph state for the dashboard.
NodeInfo
Node information for the dashboard.

Functions

add_edge
Adds an edge to the shared graph state.
add_event
Adds an event to the shared graph state.
add_node
Adds a node to the shared graph state.
dashboard_state
Get the global dashboard state for updating from the file watcher.
init_dashboard_state
Initialize the global dashboard state. Called once when the dashboard starts.
set_theme_token
Updates a theme token in the shared graph state.
start_dashboard
Starts the DevTools dashboard HTTP server using axum.

Type Aliases

AppState
Axum state type alias.