Native Shell Module
Provides a unified interface for creating and managing native application windows through multiple backend implementations: Tauri, Wry, or Headless (for testing and CI environments).
Structs
- Native
Shell - Configuration and handle for a native shell instance.
- Shell
Error - Errors that can occur when creating or managing native shell windows.
- Shell
Window - A handle to a created native window.
Enums
- Shell
Backend - The rendering backend used for the native shell window.
- Window
Event - Events that can be emitted by a native window.
Functions
- create_
window - Create a native window from the given
NativeShellconfiguration. - poll_
events - Poll for pending window events in a non-blocking fashion.